pub struct ATTITUDE_QUATERNION_DATA {
pub time_boot_ms: u32,
pub q1: f32,
pub q2: f32,
pub q3: f32,
pub q4: f32,
pub rollspeed: f32,
pub pitchspeed: f32,
pub yawspeed: f32,
pub repr_offset_q: [f32; 4],
}dialect-cubepilot only.Expand description
The attitude in the aeronautical frame (right-handed, Z-down, X-front, Y-right), expressed as quaternion. Quaternion order is w, x, y, z and a zero rotation would be expressed as (1 0 0 0).
ID: 31
Fields
time_boot_ms: u32Timestamp (time since system boot).
q1: f32Quaternion component 1, w (1 in null-rotation)
q2: f32Quaternion component 2, x (0 in null-rotation)
q3: f32Quaternion component 3, y (0 in null-rotation)
q4: f32Quaternion component 4, z (0 in null-rotation)
rollspeed: f32Roll angular speed
pitchspeed: f32Pitch angular speed
yawspeed: f32Yaw angular speed
repr_offset_q: [f32; 4]Rotation offset by which the attitude quaternion and angular speed vector should be rotated for user display (quaternion with [w, x, y, z] order, zero-rotation is [1, 0, 0, 0], send [0, 0, 0, 0] if field not supported). This field is intended for systems in which the reference attitude may change during flight. For example, tailsitters VTOLs rotate their reference attitude by 90 degrees between hover mode and fixed wing mode, thus repr_offset_q is equal to [1, 0, 0, 0] in hover mode and equal to [0.7071, 0, 0.7071, 0] in fixed wing mode.
Implementations