pub struct FIGURE_EIGHT_EXECUTION_STATUS_DATA {
pub time_usec: u64,
pub major_radius: f32,
pub minor_radius: f32,
pub orientation: f32,
pub x: i32,
pub y: i32,
pub z: f32,
pub frame: MavFrame,
}dialect-cubepilot only.Expand description
Vehicle status report that is sent out while figure eight execution is in progress (see MAV_CMD_DO_FIGURE_EIGHT). This may typically send at low rates: of the order of 2Hz.
ID: 361
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
major_radius: f32Major axis radius of the figure eight. Positive: orbit the north circle clockwise. Negative: orbit the north circle counter-clockwise.
minor_radius: f32Minor axis radius of the figure eight. Defines the radius of two circles that make up the figure.
orientation: f32Orientation of the figure eight major axis with respect to true north in [-pi,pi).
x: i32X coordinate of center point. Coordinate system depends on frame field.
y: i32Y coordinate of center point. Coordinate system depends on frame field.
z: f32Altitude of center point. Coordinate system depends on frame field.
frame: MavFrameThe coordinate system of the fields: x, y, z.
Implementations