pub struct GLOBAL_POSITION_SENSOR_DATA {}dialect-cubepilot only.Expand description
Reports measurement/estimate from a global position sensor. Used as navigation fusion source and optionally displayed in the UI.
ID: 296
Fields
time_usec: u64Timestamp of message transmission (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
processing_time: u32The time spent in processing the sensor data that is the basis for this position. The recipient can use this to improve time alignment of the data. This is the time between measurement (e.g. camera exposure time) and transmission of this message. Set to NaN if not known.
lat: i32Latitude (WGS84)
lon: i32Longitude (WGS84)
alt_ellipsoid: f32Altitude (WGS84 elipsoid), preferred if available
alt: f32Altitude (MSL - position-system specific value) use if no alt_ellipsoid available
eph: f32Standard deviation of horizontal position error
epv: f32Standard deviation of vertical position error
target_system: u8System ID (ID of target system, normally autopilot and ground station).
target_component: u8Component ID (normally 0 for broadcast).
id: u8Sensor ID
source: GlobalPositionSrcSource of position/estimate (such as GNSS, estimator, etc.)
flags: GlobalPositionFlagsStatus flags
Implementations