pub struct GPS_RAW_INT_DATA {}dialect-cubepilot only.Expand description
The global position, as returned by the Global Positioning System (GPS). This is NOT the global position estimate of the system, but rather a RAW sensor value. See message GLOBAL_POSITION_INT for the global position estimate.
ID: 24
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
lat: i32Latitude (WGS84, EGM96 ellipsoid)
lon: i32Longitude (WGS84, EGM96 ellipsoid)
alt: i32Altitude (MSL). Positive for up. Note that virtually all GPS modules provide the MSL altitude in addition to the WGS84 altitude.
eph: u16GPS HDOP horizontal dilution of position (unitless * 100). If unknown, set to: UINT16_MAX
epv: u16GPS VDOP vertical dilution of position (unitless * 100). If unknown, set to: UINT16_MAX
vel: u16GPS ground speed. If unknown, set to: UINT16_MAX
cog: u16Course over ground (NOT heading, but direction of movement) in degrees * 100, 0.0..359.99 degrees. If unknown, set to: UINT16_MAX
fix_type: GpsFixTypeGPS fix type.
satellites_visible: u8Number of satellites visible. If unknown, set to UINT8_MAX
alt_ellipsoid: i32Altitude (above WGS84, EGM96 ellipsoid). Positive for up.
h_acc: u32Position uncertainty.
v_acc: u32Altitude uncertainty.
vel_acc: u32Speed uncertainty.
hdg_acc: u32Heading / track uncertainty
yaw: u16Yaw in earth frame from north. Use 0 if this GPS does not provide yaw. Use UINT16_MAX if this GPS is configured to provide yaw and is currently unable to provide it. Use 36000 for north.
Implementations