pub struct ONBOARD_COMPUTER_STATUS_DATA {Show 21 fields
pub time_usec: u64,
pub uptime: u32,
pub ram_usage: u32,
pub ram_total: u32,
pub storage_type: [u32; 4],
pub storage_usage: [u32; 4],
pub storage_total: [u32; 4],
pub link_type: [u32; 6],
pub link_tx_rate: [u32; 6],
pub link_rx_rate: [u32; 6],
pub link_tx_max: [u32; 6],
pub link_rx_max: [u32; 6],
pub fan_speed: [i16; 4],
pub mavtype: u8,
pub cpu_cores: [u8; 8],
pub cpu_combined: [u8; 10],
pub gpu_cores: [u8; 4],
pub gpu_combined: [u8; 10],
pub temperature_board: i8,
pub temperature_core: [i8; 8],
pub status_flags: ComputerStatusFlags,
}dialect-cubepilot only.Expand description
Hardware status sent by an onboard computer.
ID: 390
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
uptime: u32Time since system boot.
ram_usage: u32Amount of used RAM on the component system. A value of UINT32_MAX implies the field is unused.
ram_total: u32Total amount of RAM on the component system. A value of UINT32_MAX implies the field is unused.
storage_type: [u32; 4]Storage type: 0: HDD, 1: SSD, 2: EMMC, 3: SD card (non-removable), 4: SD card (removable). A value of UINT32_MAX implies the field is unused.
storage_usage: [u32; 4]Amount of used storage space on the component system. A value of UINT32_MAX implies the field is unused.
storage_total: [u32; 4]Total amount of storage space on the component system. A value of UINT32_MAX implies the field is unused.
link_type: [u32; 6]Link type: 0-9: UART, 10-19: Wired network, 20-29: Wifi, 30-39: Point-to-point proprietary, 40-49: Mesh proprietary
link_tx_rate: [u32; 6]Network traffic from the component system. A value of UINT32_MAX implies the field is unused.
link_rx_rate: [u32; 6]Network traffic to the component system. A value of UINT32_MAX implies the field is unused.
link_tx_max: [u32; 6]Network capacity from the component system. A value of UINT32_MAX implies the field is unused.
link_rx_max: [u32; 6]Network capacity to the component system. A value of UINT32_MAX implies the field is unused.
fan_speed: [i16; 4]Fan speeds. A value of INT16_MAX implies the field is unused.
mavtype: u8Type of the onboard computer: 0: Mission computer primary, 1: Mission computer backup 1, 2: Mission computer backup 2, 3: Compute node, 4-5: Compute spares, 6-9: Payload computers.
cpu_cores: [u8; 8]CPU usage on the component in percent (100 - idle). A value of UINT8_MAX implies the field is unused.
cpu_combined: [u8; 10]Combined CPU usage as the last 10 slices of 100 MS (a histogram). This allows to identify spikes in load that max out the system, but only for a short amount of time. A value of UINT8_MAX implies the field is unused.
gpu_cores: [u8; 4]GPU usage on the component in percent (100 - idle). A value of UINT8_MAX implies the field is unused.
gpu_combined: [u8; 10]Combined GPU usage as the last 10 slices of 100 MS (a histogram). This allows to identify spikes in load that max out the system, but only for a short amount of time. A value of UINT8_MAX implies the field is unused.
temperature_board: i8Temperature of the board. A value of INT8_MAX implies the field is unused.
temperature_core: [i8; 8]Temperature of the CPU core. A value of INT8_MAX implies the field is unused.
status_flags: ComputerStatusFlagsBitmap of status flags.
Implementations