pub struct PROTOCOL_VERSION_DATA {
pub version: u16,
pub min_version: u16,
pub max_version: u16,
pub spec_version_hash: [u8; 8],
pub library_version_hash: [u8; 8],
}Nothing (Deprecated since 2025-11)dialect-cubepilot only.Expand description
Version and capability of protocol version. This message can be requested with MAV_CMD_REQUEST_MESSAGE and is used as part of the handshaking to establish which MAVLink version should be used on the network. Every node should respond to a request for PROTOCOL_VERSION to enable the handshaking. Library implementers should consider adding this into the default decoding state machine to allow the protocol core to respond directly.
ID: 300
Fields
version: u16Nothing (Deprecated since 2025-11)Currently active MAVLink version number * 100: v1.0 is 100, v2.0 is 200, etc.
min_version: u16Nothing (Deprecated since 2025-11)Minimum MAVLink version supported
max_version: u16Nothing (Deprecated since 2025-11)Maximum MAVLink version supported (set to the same value as version by default)
spec_version_hash: [u8; 8]Nothing (Deprecated since 2025-11)The first 8 bytes (not characters printed in hex!) of the git hash.
library_version_hash: [u8; 8]Nothing (Deprecated since 2025-11)The first 8 bytes (not characters printed in hex!) of the git hash.
Implementations