pub struct SET_GPS_GLOBAL_ORIGIN_DATA {
pub latitude: i32,
pub longitude: i32,
pub altitude: i32,
pub target_system: u8,
pub time_usec: u64,
}๐Deprecated: See
MAV_CMD_DO_SET_GLOBAL_ORIGIN (Superseded since 2025-04)Available on crate feature
dialect-cubepilot only.Expand description
Sets the GPS coordinates of the vehicle local origin (0,0,0) position. Vehicle should emit GPS_GLOBAL_ORIGIN irrespective of whether the origin is changed. This enables transform between the local coordinate frame and the global (GPS) coordinate frame, which may be necessary when (for example) indoor and outdoor settings are connected and the MAV should move from in- to outdoor.
ID: 48
Fields
latitude: i32๐Deprecated: See
MAV_CMD_DO_SET_GLOBAL_ORIGIN (Superseded since 2025-04)Latitude (WGS84)
longitude: i32๐Deprecated: See
MAV_CMD_DO_SET_GLOBAL_ORIGIN (Superseded since 2025-04)Longitude (WGS84)
altitude: i32๐Deprecated: See
MAV_CMD_DO_SET_GLOBAL_ORIGIN (Superseded since 2025-04)Altitude (MSL). Positive for up.
target_system: u8๐Deprecated: See
MAV_CMD_DO_SET_GLOBAL_ORIGIN (Superseded since 2025-04)System ID
time_usec: u64๐Deprecated: See
MAV_CMD_DO_SET_GLOBAL_ORIGIN (Superseded since 2025-04)Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
Implementations